==> cdktf-cdktf-provider-google-0.6.1.tar.gz: package/lib/data-google-redis-instance.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataGoogleRedisInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
     * The ID of the instance or a fully qualified identifier for the instance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/redis_instance#name DataGoogleRedisInstance#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/redis_instance#project DataGoogleRedisInstance#project}.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * The name of the Redis region of the instance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/redis_instance#region DataGoogleRedisInstance#region}
     *
     * @stability stable
     */
    readonly region?: string;
}
/**
 * @stability stable
 */
export declare class DataGoogleRedisInstanceServerCaCerts extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get cert(): string;
    /**
     * @stability stable
     */
    get createTime(): string;
    /**
     * @stability stable
     */
    get expireTime(): string;
    /**
     * @stability stable
     */
    get serialNumber(): string;
    /**
     * @stability stable
     */
    get sha1Fingerprint(): string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/d/redis_instance google_redis_instance}.
 *
 * @stability stable
 */
export declare class DataGoogleRedisInstance extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/d/redis_instance google_redis_instance} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataGoogleRedisInstanceConfig);
    /**
     * @stability stable
     */
    get alternativeLocationId(): string;
    /**
     * @stability stable
     */
    get authEnabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get authString(): string;
    /**
     * @stability stable
     */
    get authorizedNetwork(): string;
    /**
     * @stability stable
     */
    get connectMode(): string;
    /**
     * @stability stable
     */
    get createTime(): string;
    /**
     * @stability stable
     */
    get currentLocationId(): string;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    labels(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    get locationId(): string;
    /**
     * @stability stable
     */
    get memorySizeGb(): number;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get persistenceIamIdentity(): string;
    /**
     * @stability stable
     */
    get port(): number;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    redisConfigs(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    get redisVersion(): string;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    /**
     * @stability stable
     */
    get reservedIpRange(): string;
    /**
     * @stability stable
     */
    serverCaCerts(index: string): DataGoogleRedisInstanceServerCaCerts;
    /**
     * @stability stable
     */
    get tier(): string;
    /**
     * @stability stable
     */
    get transitEncryptionMode(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.6.38.tar.gz: package/lib/data-google-redis-instance.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleRedisInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the instance or a fully qualified identifier for the instance.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/redis_instance#name DataGoogleRedisInstance#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/redis_instance#project DataGoogleRedisInstance#project}
    */
    readonly project?: string;
    /**
    * The name of the Redis region of the instance.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/redis_instance#region DataGoogleRedisInstance#region}
    */
    readonly region?: string;
}
export declare class DataGoogleRedisInstanceServerCaCerts extends cdktf.ComplexComputedList {
    get cert(): string;
    get createTime(): string;
    get expireTime(): string;
    get serialNumber(): string;
    get sha1Fingerprint(): string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google/d/redis_instance google_redis_instance}
*/
export declare class DataGoogleRedisInstance extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google/d/redis_instance google_redis_instance} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleRedisInstanceConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleRedisInstanceConfig);
    get alternativeLocationId(): string;
    get authEnabled(): cdktf.IResolvable;
    get authString(): string;
    get authorizedNetwork(): string;
    get connectMode(): string;
    get createTime(): string;
    get currentLocationId(): string;
    get displayName(): string;
    get host(): string;
    get id(): string;
    labels(key: string): string | cdktf.IResolvable;
    get locationId(): string;
    get memorySizeGb(): number;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get persistenceIamIdentity(): string;
    get port(): number;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    redisConfigs(key: string): string | cdktf.IResolvable;
    get redisVersion(): string;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    get reservedIpRange(): string;
    serverCaCerts(index: string): DataGoogleRedisInstanceServerCaCerts;
    get tier(): string;
    get transitEncryptionMode(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
